@@ -1,6 +1,5 @@
 package Form::Factory::Feature;
-our $VERSION = '0.007';
-
+our $VERSION = '0.008';
 
 use Moose::Role;
 
@@ -12,18 +11,18 @@ Form::Factory::Feature - Interface for objects that modify how actions work
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
   package MyApp::Feature::Foo;
-our $VERSION = '0.007';
-
-
   use Moose;
 
   with qw( Form::Factory::Feature );
 
+  package Form::Factory:;Feature::Custom::Foo;
+  sub register_implementation { 'MyApp::Feature::Foo' }
+
 =head1 DESCRIPTION
 
 A feature modifies what the form does during processing.
