@@ -1,6 +1,5 @@
 package Form::Factory::Processor;
-our $VERSION = '0.007';
-
+our $VERSION = '0.008';
 
 use Moose;
 use Moose::Exporter;
@@ -9,7 +8,6 @@ use Form::Factory::Action;
 use Form::Factory::Action::Meta::Class;
 use Form::Factory::Action::Meta::Attribute::Control;
 use Form::Factory::Processor::DeferredValue;
-use Form::Factory::Util qw( class_name_from_name );
 
 Moose::Exporter->setup_import_methods(
     as_is     => [ qw( deferred_value ) ],
@@ -26,14 +24,11 @@ Form::Factory::Processor - Moos-ish helper for action classes
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
   package MyApp::Action::Foo;
-our $VERSION = '0.007';
-
-
   use Form::Factory::Processor;
 
   has_control name => (
@@ -171,11 +166,7 @@ sub has_control {
     unshift @{ $args->{traits} }, 'Form::Control';
 
     for my $name (keys %{ $args->{features} }) {
-        my $feature_class = class_name_from_name('Feature::Control', $name);
-        unless (Class::MOP::load_class($feature_class)) {
-            die $@ if $@;
-            die "cannot load $feature_class";
-        }
+        my $feature_class = Form::Factory->control_feature_class($name);
         next unless $feature_class->does('Form::Factory::Feature::Role::BuildAttribute');
 
         $feature_class->build_attribute(
